package airportProject;

import de.fhpotsdam.unfolding.data.Feature;
import de.fhpotsdam.unfolding.data.PointFeature;
import de.fhpotsdam.unfolding.geo.Location;
import processing.core.PConstants;
import processing.core.PGraphics;

public class AirportMarker extends CommonMarker {
	
	private int SIZE = 7;
	
	public AirportMarker(Location location) {
		super(location);
	}

	public AirportMarker(Feature airport) {
		super(((PointFeature)airport).getLocation(), airport.getProperties());
	}
	
	// Airport marker
	public void drawMarker(PGraphics pg, float x, float y) {
		pg.pushStyle();
		
		int[] rgb = colorMap(getAltitude());
		int blueCurr = pg.color(rgb[0], rgb[1], rgb[2]);
		//System.out.println(rgb[0] + " " + rgb[1] + " " + rgb[2]);
		
		// Drawing triangle for each airport
		pg.fill(blueCurr);
		pg.ellipse(x, y, SIZE, SIZE);
		
		// Restore previous drawing style
		pg.popStyle();
	}

	@Override
	public void showTitle(PGraphics pg, float x, float y) {
		
		String name = getName() + "( " + getCode() + "), " + getCity() + " ";
		String alt = "Altitude : " + getAltitude() + " ft";
		float dx = Math.max(pg.textWidth(name), pg.textWidth(alt));
		int dy = 39;
		int dyText = 33;
		
	
		pg.pushStyle();
		
		pg.fill(blueLight);
		pg.textSize(12);
		pg.rectMode(PConstants.CORNER);
		pg.rect(x, y-SIZE-dy, dx+6, dy);
		pg.fill(0, 0, 0);
		pg.textAlign(PConstants.LEFT, PConstants.TOP);
		pg.text(name, x+3, y-SIZE-dyText);
		pg.text(alt, x+3, y-SIZE-18);
		
		pg.popStyle();
	}

	public int getID() {
		return Integer.parseInt(getStringProperty("ID"));
	}
	
	private String getName() {
		return getStringProperty("name");
	}
	
	private String getCity() {
		return getStringProperty("city");
	}
	
	private String getCode() {
		return getStringProperty("code3");
	}
	
	private float getAltitude() {
		return Float.parseFloat(getStringProperty("altitude"));
	}

	private int[] colorMap(float altCurr) {
		int[] rgb = new int[3];
		
		// Relative altitude
		float da = (float) (AirportMap.altMax - AirportMap.altMin);
		float di = (float)(altCurr - AirportMap.altMin) / da;
		
		float dRed = (float)(rMax - rMin);
		float dGreen = (float)(gMax - gMin);
		float dBlue = (float)(bMax - bMin);
		
		rgb[0] = (int)(rMin + di * dRed);	//Mapped red
		rgb[1] = (int)(gMin + di * dGreen);	//Mapped green
		rgb[2] = (int)(bMin + di * dBlue);	//Mapped blue

		return rgb;
	}
	
}
