package airportProject;

import de.fhpotsdam.unfolding.data.Feature;
import de.fhpotsdam.unfolding.data.PointFeature;
import de.fhpotsdam.unfolding.geo.Location;
import processing.core.PConstants;
import processing.core.PGraphics;

public class CityMarker extends CommonMarker {
	
	public static int SIZE = 5;
	
	public CityMarker(Location location) {
		super(location);
	}
	
	public CityMarker(Feature city) {
		super(((PointFeature)city).getLocation(), city.getProperties());
	}

	// Implementation of the method to draw marker on the map
	public void drawMarker(PGraphics pg, float x, float y) {
		
		pg.pushStyle();
		
		// Drawing triangle for each city
		pg.fill(purple);
		pg.triangle(x, y-SIZE, x-SIZE, y+SIZE, x+SIZE, y+SIZE);
		
		// Restore previous drawing style
		pg.popStyle();
		
	}
	
	// Show the title of the city if selected
	public void showTitle(PGraphics pg, float x, float y) {
		
		String name = getCity() + ", " + getCountry() + " ";
		String pop = "Population : " + getPopulation() + " Millions";
		float dx = Math.max(pg.textWidth(name), pg.textWidth(pop));
		int dy = 39;
		int dyText = 33;
		
		pg.pushStyle();
		
		pg.fill(yellow);
		pg.textSize(12);
		pg.rectMode(PConstants.CORNER);
		pg.rect(x, y-SIZE-dy, dx+6, dy);
		pg.fill(0, 0, 0);
		pg.textAlign(PConstants.LEFT, PConstants.TOP);
		pg.text(name, x+3, y-SIZE-dyText);
		pg.text(pop, x+3, y-SIZE-18);
		
		pg.popStyle();
		
	}
	
	private String getCity() {
		return getStringProperty("name");
	}
	
	private String getCountry() {
		return getStringProperty("country");
	}
	
	private float getPopulation() {
		return Float.parseFloat(getStringProperty("population"));
	}
	
}
